[−][src]Enum async_graphql::MaybeUndefined
Similar to Option, but it has three states, undefined, null and x.
Spec: https://spec.graphql.org/June2018/#sec-Null-Value
Variants
Implementations
impl<T> MaybeUndefined<T>[src]
pub fn is_undefined(&self) -> bool[src]
Returns true if the MaybeUndefined
pub fn is_null(&self) -> bool[src]
Returns true if the MaybeUndefined
pub fn value(&self) -> Option<&T>[src]
Borrow the value, returns None if the value is undefined or null, otherwise returns Some(T).
pub fn take(self) -> Option<T>[src]
Convert MaybeUndefined