ErrorExtensions

Trait ErrorExtensions 

pub trait ErrorExtensions: Sized {
    // Required method
    fn extend(&self) -> Error;

    // Provided method
    fn extend_with<C>(self, cb: C) -> Error
       where C: FnOnce(&Self, &mut ErrorExtensionValues) { ... }
}
An error which can be extended into a Error.

Required Methods

fn extend(&self) -> Error

Convert the error to a Error.

Provided Methods

fn extend_with<C>(self, cb: C) -> Error
where C: FnOnce(&Self, &mut ErrorExtensionValues),

Add extensions to the error, using a callback to make the extensions.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<E: Display> ErrorExtensions for &E

Source

fn extend(&self) -> Error

Implementors